@@ -1156,9 +1156,11 @@ class FilesAAPI(AAPIView):
 
 class ScansAAPI(AAPIView):
 
-    async def list(self, offset=None, limit=None, session=None, raw=None):
+    async def list(self, status=None, offset=None, limit=None,
+                   session=None, raw=None):
         """ List a page of the collection of scans
 
+        :param status: scans' status filtering (default None)
         :param offset: offset for pagination (default None)
         :param limit: custom limit for pagination (default None)
         :param session: custom session to use (default None)
@@ -1168,6 +1170,8 @@ class ScansAAPI(AAPIView):
 
         """
         query = self._askpage(offset, limit)
+        if status:
+            query['status'] = status
         res = await self._get('/scans', session, query)
         schema = Paginated(ScanSchema)()
         return self._format(res, raw, schema=schema)
